@@ -2,14 +2,12 @@ package org.gcube.socialnetworking.token;
 
 import java.net.MalformedURLException;
 import java.net.URL;
+import java.util.HashMap;
+import java.util.Map;
 
 public class URLToken extends ReplaceableToken {
-
 	
-	private String getReplacement(URL url) {
-		StringBuilder sb = new StringBuilder();
-		return sb.toString();
-	}
+	private boolean replaced;
 	
 	public URLToken(Token token, URL url) {
 		super(token);
@@ -30,4 +28,14 @@ public class URLToken extends ReplaceableToken {
 		
 	}
 	
+	public String getTokenReplacement() {
+		if(!replaced) {
+			Map<String, String> anchorAttibutes = new HashMap<>(1);
+			anchorAttibutes.put("target", "_blank");
+			tokenReplacement = createLink(token, token, anchorAttibutes);
+			replaced = true;
+		}
+		return super.getTokenReplacement();
+	}
+	
 }
